@@ -2,12 +2,13 @@ package Log::Dispatch::Screen::Color;
 use strict;
 use warnings;
 use base 'Log::Dispatch::Screen';
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Params::Validate qw(validate HASHREF);
 Params::Validate::validation_options( allow_extra => 1 );
 
 use Term::ANSIColor ();
+require Win32::Console::ANSI if $^O eq 'MSWin32';
 
 our $DEFAULT_COLOR = {
     debug => {},
@@ -153,6 +154,8 @@ Log::Dispatch::Screen::Color - attached color for Log::Dispatch::Screen
 
 Log::Dispatch::Screen::Color is attaching a color safely for Screen. because L<Log::Dispatch::Colorful> has rewrite L<Log::Dispatch> method problem.
 
+Win32 is supported.
+
 =head1 OVERRIDES
 
 Setting $Log::Dispatch::Screen::Color::DEFAULT_COLOR overrides. default color is changed.
@@ -161,10 +164,6 @@ Setting $Log::Dispatch::Screen::Color::DEFAULT_COLOR overrides. default color is
     text => 'red',
   };
 
-=head1 TODO
-
-for win32
-
 =head1 AUTHOR
 
 Kazuhiro Osawa E<lt>yappo <at> shibuya <döt> plE<gt>
